==> cms-db_v0.9.tar.gz: admin/mobile.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('frame');

require_once('mobile.inc.php');

if (!mobile() && !tablet()) die();
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<meta name="viewport" content="width = device-width, height = device-height, initial-scale = 1.0" />
		<title>cms -db <?php echo (tablet()) ? 'tablet' : 'mobile' ?></title>
		<style type="text/css">
		<!--
		body, html {
			padding: 0;
			margin: 0;
			font-family: sans-serif;
			font-size: 12pt;
			background: #eee;
		}
		#top {
			background: #f4f4f4;
			border-bottom: 1px solid #aaa;
			padding: .5em;
			margin-bottom: 1em;
		}
		h1 {
			margin: 0;
			font-size: 1.2em;
			margin-bottom: .5em;
			border-bottom: 4px solid #e4e4e4;
			font-weight: bold;
		}
		h1 span {
			font-size: .8em;
			color: #444;
			font-weight: normal;
		}
		#menu {
			margin: 0 -.5em 0 -.5em;
		}
		#menu a:link, #menu a:visited, #menu a:active, #menu a:hover {
			display: block;
			padding: 1em;
			border-top: 1px solid #ddd;
			border-bottom: 1px solid #ddd;
			margin: 0 0 -1px 0;
			color: #000;
			text-decoration: none;
			font-size: .8333333333em;
		}
		#menu a:hover, #menu a:active, #menu a:focus {
			<?php include('../data/settings/admin.inc.php') ?>
			background: url("mobile-menubg.png") center center rgb(<?php echo $bg_r ?>, <?php echo $bg_g ?>, <?php echo $bg_b ?>);
			color: rgb(<?php echo $text_r ?>, <?php echo $text_g ?>, <?php echo $text_b ?>);
		}
		#menutoggle {
			display: block;
			padding: 10px;
			margin: -.5em;
			background: url("mobile-menutoggle.png") no-repeat;
			height: 20px;
		}
		#menutoggle.menutoggleup {
			background-position: center bottom !important;
		}
		#menutoggle.menutoggledown {
			background-position: center top !important;
		}
		<?php
		if (tablet()) {
		?>
		#top {
			width: 14em; /* was: 12.5em */
			border-right: 1px solid #aaa;
			margin-bottom: 0;
			border-bottom: none;
		}
		#content {
			position: absolute;
			top: 0;
			left: 200px;
			right: 0;
		}
		<?php
		}
		?>
		-->
		</style>
		<script src="jquery.js" type="text/javascript"></script>
		<script type="text/javascript">
		/* <![CDATA[ */
		/* Iframe resizing functions */
		function resizeIframe() {
			<?php
			if (tablet()) {
			?>
			var left = $("#menu").width() + 1;
			$("#content").css("left", left);
			var contentwidth = $(window).width() - $("#menu").width() - 1 + "px";
			<?php
			} elseif (mobile()) {
			?>
			var contentwidth = "100%";
			<?php
			}
			?>
			parent.frames.content.scroll(0,0); // bug fix for opera mini or netfront
			var iframecontents = $("#content").contents();
			var height = iframecontents.find("html").height();
			<?php
			if (tablet()) {
			?>
			if (height < $(window).height()) {
				var height = $(window).height();
			}
			if ($("#top").height() < height) {
				$("#top").height(height);
			}
			<?php
			}
			?>
			var width = document.getElementById("content").contentWindow.document.body.scrollWidth;
			var width = (width > $(window).width()) ? width+"px" : contentwidth;
			$("#content").css("height", height+"px");
			$("#content").css("width", width);
		}
		function addResetEvent() {
			var iframecontents = $("#content").contents();
			iframecontents.find("a, input[type=submit]").click(function(){ resetWidth(); });
		}
		function resetWidth() {
			<?php
			if (mobile()) {
			?>
			$("#content").css("width", "100%");
			<?php
			} elseif (tablet()) {
			?>
			var left = $("#menu").width() + 1;
			var contentwidth = $(window).width() - $("#menu").width() - 1;
			$("#content").css("left", left + "px");
			$("#content").css("width", contentwidth + "px");
			$("#top").height("auto");
			<?php
			}
			?>
		}
		
		/* Initialize Iframe resizing */
		$(window).resize(resizeIframe);
		window.setInterval("resizeIframe()", 1000);
		
		/* Menu functions */
		function hideMenu() {
			$("#menutoggle").attr("class", "menutoggledown");
			//$("#menu").slideUp("slow")
			$("#menu").hide();
			window.scroll(0,0);
		}
		function showMenu() {
			$("#menutoggle").attr("class", "menutoggleup");
			//$("#menu").slideDown("slow");
			$("#menu").show();
			window.scroll(0,0);
		}
		function toggleMenu() {
			if ($("#menutoggle").attr("class") == "menutoggledown") {
				showMenu();
			} else {
				hideMenu();
			}
		}
		
		/* Initialize Menu */
		$(function() {
			$("#menutoggle").click(function() {
				toggleMenu();
			});
			if (screen.width >= 320) {
				$("#menu a").each(function() {
					$(this).prepend('<img src="./big-icons/'+$(this).attr("rel")+'.png" width="24" height="24" alt="" />')
						.css({'line-height': '24px'})
						.find("img")
						.css({'border': 'none', 'vertical-align': 'middle', 'margin-right': '.5em'});
				});
			} else {
				$("#menu a").each(function() {
					$(this).prepend('<img src="./big-icons/'+$(this).attr("rel")+'.png" width="16" height="16" alt="" />')
						.css({'line-height': '16px', 'padding': '.5em'})
						.find("img")
						.css({'border': 'none', 'vertical-align': 'middle', 'margin-right': '.5em'});
				});
			}
		});
		
		/* Menu Click events */
		$(function() {
			resetWidth();
			$("#menu a").click(function() {
				resetWidth();
				<?php
				if (mobile()) {
				?>
				if (navigator.userAgent.indexOf("Opera Mini") == -1) {
					setTimeout('hideMenu()', 500);
				}
				<?php
				} else {
				?>
				window.scroll(0,0);
				<?php
				}
				?>
			});
		});
		/* ]]> */
		</script>
		<script type="text/javascript">
		/*<![CDATA[*/
		var text_update = '<?php locale_escape('button_update', "'") ?>';
		var text_update_none = '<?php locale_escape('button_update-none', "'") ?>';
		var php_session_id = '<?php echo SID.csrf_protection_get(); ?>';
		/*]]>*/
		</script>
		<script src="ajax.js" type="text/javascript"></script>
		<?php include('../data/settings/update.inc.php'); if ($autoupdate == 'on') { ?>
			<script src="update.js" type="text/javascript"></script>
		<?php } ?>
	</head>
	<body>
	
		<div id="top">
			<h1>cms -db <span><?php echo (tablet()) ? 'tablet' : 'mobile' ?></span></h1>
			<div id="menu">
				<p>
					<a href="pages.php?<?php echo SID; csrf_protection_get_html() ?>" rel="pages" target="content"><?php locale('desc_pages') ?></a>
					<a href="files.php?<?php echo SID; csrf_protection_get_html() ?>" rel="files" target="content"><?php locale('desc_files') ?></a>
					<a href="includes.php?<?php echo SID; csrf_protection_get_html() ?>" rel="includes" target="content"><?php locale('desc_includes') ?></a>
					<a href="settings.php?<?php echo SID; csrf_protection_get_html() ?>" rel="settings" target="content"><?php locale('desc_settings') ?></a>
					<a href="template.php?<?php echo SID; csrf_protection_get_html() ?>" rel="template" target="content"><?php locale('desc_template') ?></a>
					<a href="space.php?<?php echo SID; csrf_protection_get_html() ?>" rel="space" target="content"><?php locale('desc_space') ?></a>
					<a href="fileperms.php?<?php echo SID; csrf_protection_get_html() ?>" rel="fileperms" target="content"><?php locale('desc_fileperms') ?></a>
					<a href="backup.php?<?php echo SID; csrf_protection_get_html() ?>" rel="backup" target="content"><?php locale('desc_backup') ?></a>
					<a href="guestbook.php?<?php echo SID; csrf_protection_get_html() ?>" rel="guestbook" target="content"><?php locale('desc_guestbook') ?></a>
					<a href="blog.php?<?php echo SID; csrf_protection_get_html() ?>" rel="blog" target="content"><?php locale('desc_blog') ?></a>
					<a href="stats.php?<?php echo SID; csrf_protection_get_html() ?>" rel="stats" target="content"><?php locale('desc_stats') ?></a>
					<a href="recyclebin.php?<?php echo SID; csrf_protection_get_html() ?>" rel="recyclebin" target="content"><?php locale('desc_recyclebin') ?></a>
				</p>
				<p>
					<a href="updateinfo.php?<?php echo SID; csrf_protection_get_html() ?>" rel="update-manual" target="content" id="updatebutton_mobile"><?php locale('button_update-manual') ?></a>
					<a href="../" rel="preview" target="content"><?php locale('button_preview') ?></a>
					<a href="version.php?locale=<?php echo $_SESSION['CMS-Locale'] ?>" rel="about" target="content"><?php locale('button_about') ?></a>
					<a href="logout.php?<?php echo SID; csrf_protection_get_html() ?>" rel="logout"><?php locale('button_logout') ?></a>
				</p>
			</div>
			<?php
			if (mobile()) {
				echo '<a id="menutoggle" class="menutoggleup" href="#"></a>';
			}
			?>
		</div>
		
		<noscript>Javascript is needed for cms -db.</noscript>
		
		<iframe onload="resizeIframe();addResetEvent()" onunload="resetWidth()" src="about:blank" id="content" name="content" frameborder="0" style="height: 10000px" width="100%">Your web browser does not support cms -db.</iframe>
	
	</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/mobile.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('frame');

require_once('mobile.inc.php');

if (!mobile() && !tablet()) die();
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<meta name="viewport" content="width = device-width, height = device-height, initial-scale = 1.0" />
		<title>cms -db <?php echo (tablet()) ? 'tablet' : 'mobile' ?></title>
		<style type="text/css">
		<!--
		body, html {
			padding: 0;
			margin: 0;
			font-family: sans-serif;
			font-size: 12pt;
			background: #eee;
		}
		#top {
			background: #f4f4f4;
			border-bottom: 1px solid #aaa;
			padding: .5em;
			margin-bottom: 1em;
		}
		h1 {
			margin: 0;
			font-size: 1.2em;
			margin-bottom: .5em;
			border-bottom: 4px solid #e4e4e4;
			font-weight: bold;
		}
		h1 span {
			font-size: .8em;
			color: #444;
			font-weight: normal;
		}
		#menu {
			margin: 0 -.5em 0 -.5em;
		}
		#menu a:link, #menu a:visited, #menu a:active, #menu a:hover {
			display: block;
			padding: 1em;
			border-top: 1px solid #ddd;
			border-bottom: 1px solid #ddd;
			margin: 0 0 -1px 0;
			color: #000;
			text-decoration: none;
			font-size: .8333333333em;
		}
		#menu a:hover, #menu a:active, #menu a:focus {
			<?php include('../data/settings/admin.inc.php') ?>
			background: url("mobile-menubg.png") center center rgb(<?php echo $bg_r ?>, <?php echo $bg_g ?>, <?php echo $bg_b ?>);
			color: rgb(<?php echo $text_r ?>, <?php echo $text_g ?>, <?php echo $text_b ?>);
		}
		#menutoggle {
			display: block;
			padding: 10px;
			margin: -.5em;
			background: url("mobile-menutoggle.png") no-repeat;
			height: 20px;
		}
		#menutoggle.menutoggleup {
			background-position: center bottom !important;
		}
		#menutoggle.menutoggledown {
			background-position: center top !important;
		}
		<?php
		if (tablet()) {
		?>
		#top {
			width: 14em; /* was: 12.5em */
			border-right: 1px solid #aaa;
			margin-bottom: 0;
			border-bottom: none;
		}
		#content {
			position: absolute;
			top: 0;
			left: 200px;
			right: 0;
		}
		<?php
		}
		?>
		-->
		</style>
		<script src="jquery.js" type="text/javascript"></script>
		<script type="text/javascript">
		/* <![CDATA[ */
		/* Iframe resizing functions */
		function resizeIframe() {
			<?php
			if (tablet()) {
			?>
			var left = $("#menu").width() + 1;
			$("#content").css("left", left);
			var contentwidth = $(window).width() - $("#menu").width() - 1 + "px";
			<?php
			} elseif (mobile()) {
			?>
			var contentwidth = "100%";
			<?php
			}
			?>
			parent.frames.content.scroll(0,0); // bug fix for opera mini or netfront
			var iframecontents = $("#content").contents();
			var height = iframecontents.find("html").height();
			<?php
			if (tablet()) {
			?>
			if (height < $(window).height()) {
				var height = $(window).height();
			}
			if ($("#top").height() < height) {
				$("#top").height(height);
			}
			<?php
			}
			?>
			var width = document.getElementById("content").contentWindow.document.body.scrollWidth;
			var width = (width > $(window).width()) ? width+"px" : contentwidth;
			$("#content").css("height", height+"px");
			$("#content").css("width", width);
		}
		function addResetEvent() {
			var iframecontents = $("#content").contents();
			iframecontents.find("a, input[type=submit]").click(function(){ resetWidth(); });
		}
		function resetWidth() {
			<?php
			if (mobile()) {
			?>
			$("#content").css("width", "100%");
			<?php
			} elseif (tablet()) {
			?>
			var left = $("#menu").width() + 1;
			var contentwidth = $(window).width() - $("#menu").width() - 1;
			$("#content").css("left", left + "px");
			$("#content").css("width", contentwidth + "px");
			$("#top").height("auto");
			<?php
			}
			?>
		}
		
		/* Initialize Iframe resizing */
		$(window).resize(resizeIframe);
		window.setInterval("resizeIframe()", 1000);
		
		/* Menu functions */
		function hideMenu() {
			$("#menutoggle").attr("class", "menutoggledown");
			//$("#menu").slideUp("slow")
			$("#menu").hide();
			window.scroll(0,0);
		}
		function showMenu() {
			$("#menutoggle").attr("class", "menutoggleup");
			//$("#menu").slideDown("slow");
			$("#menu").show();
			window.scroll(0,0);
		}
		function toggleMenu() {
			if ($("#menutoggle").attr("class") == "menutoggledown") {
				showMenu();
			} else {
				hideMenu();
			}
		}
		
		/* Initialize Menu */
		$(function() {
			$("#menutoggle").click(function() {
				toggleMenu();
			});
			if (screen.width >= 320) {
				$("#menu a").each(function() {
					$(this).prepend('<img src="./big-icons/'+$(this).attr("rel")+'.png" width="24" height="24" alt="" />')
						.css({'line-height': '24px'})
						.find("img")
						.css({'border': 'none', 'vertical-align': 'middle', 'margin-right': '.5em'});
				});
			} else {
				$("#menu a").each(function() {
					$(this).prepend('<img src="./big-icons/'+$(this).attr("rel")+'.png" width="16" height="16" alt="" />')
						.css({'line-height': '16px', 'padding': '.5em'})
						.find("img")
						.css({'border': 'none', 'vertical-align': 'middle', 'margin-right': '.5em'});
				});
			}
		});
		
		/* Menu Click events */
		$(function() {
			resetWidth();
			$("#menu a").click(function() {
				resetWidth();
				<?php
				if (mobile()) {
				?>
				if (navigator.userAgent.indexOf("Opera Mini") == -1) {
					setTimeout('hideMenu()', 500);
				}
				<?php
				} else {
				?>
				window.scroll(0,0);
				<?php
				}
				?>
			});
		});
		/* ]]> */
		</script>
		<script type="text/javascript">
		/*<![CDATA[*/
		var text_update = '<?php locale_escape('button_update', "'") ?>';
		var text_update_none = '<?php locale_escape('button_update-none', "'") ?>';
		var php_session_id = '<?php echo SID.csrf_protection_get(); ?>';
		/*]]>*/
		</script>
		<script src="ajax.js" type="text/javascript"></script>
		<?php include('../data/settings/update.inc.php'); if ($autoupdate == 'on') { ?>
			<script src="update.js" type="text/javascript"></script>
		<?php } ?>
	</head>
	<body>
	
		<div id="top">
			<h1>cms -db <span><?php echo (tablet()) ? 'tablet' : 'mobile' ?></span></h1>
			<div id="menu">
				<p>
					<a href="pages.php?<?php echo SID; csrf_protection_get_html() ?>" rel="pages" target="content"><?php locale('desc_pages') ?></a>
					<a href="files.php?<?php echo SID; csrf_protection_get_html() ?>" rel="files" target="content"><?php locale('desc_files') ?></a>
					<a href="includes.php?<?php echo SID; csrf_protection_get_html() ?>" rel="includes" target="content"><?php locale('desc_includes') ?></a>
					<a href="settings.php?<?php echo SID; csrf_protection_get_html() ?>" rel="settings" target="content"><?php locale('desc_settings') ?></a>
					<a href="template.php?<?php echo SID; csrf_protection_get_html() ?>" rel="template" target="content"><?php locale('desc_template') ?></a>
					<a href="space.php?<?php echo SID; csrf_protection_get_html() ?>" rel="space" target="content"><?php locale('desc_space') ?></a>
					<a href="fileperms.php?<?php echo SID; csrf_protection_get_html() ?>" rel="fileperms" target="content"><?php locale('desc_fileperms') ?></a>
					<a href="backup.php?<?php echo SID; csrf_protection_get_html() ?>" rel="backup" target="content"><?php locale('desc_backup') ?></a>
					<a href="guestbook.php?<?php echo SID; csrf_protection_get_html() ?>" rel="guestbook" target="content"><?php locale('desc_guestbook') ?></a>
					<a href="blog.php?<?php echo SID; csrf_protection_get_html() ?>" rel="blog" target="content"><?php locale('desc_blog') ?></a>
					<a href="stats.php?<?php echo SID; csrf_protection_get_html() ?>" rel="stats" target="content"><?php locale('desc_stats') ?></a>
					<a href="recyclebin.php?<?php echo SID; csrf_protection_get_html() ?>" rel="recyclebin" target="content"><?php locale('desc_recyclebin') ?></a>
				</p>
				<p>
					<a href="updateinfo.php?<?php echo SID; csrf_protection_get_html() ?>" rel="update-manual" target="content" id="updatebutton_mobile"><?php locale('button_update-manual') ?></a>
					<a href="../" rel="preview" target="content"><?php locale('button_preview') ?></a>
					<a href="version.php?locale=<?php echo $_SESSION['CMS-Locale'] ?>" rel="about" target="content"><?php locale('button_about') ?></a>
					<a href="logout.php?<?php echo SID; csrf_protection_get_html() ?>" rel="logout"><?php locale('button_logout') ?></a>
				</p>
			</div>
			<?php
			if (mobile()) {
				echo '<a id="menutoggle" class="menutoggleup" href="#"></a>';
			}
			?>
		</div>
		
		<noscript>Javascript is needed for cms -db.</noscript>
		
		<iframe onload="resizeIframe();addResetEvent()" onunload="resetWidth()" src="about:blank" id="content" name="content" frameborder="0" style="height: 10000px" width="100%">Your web browser does not support cms -db.</iframe>
	
	</body>
</html>
